![Rosy](http://ff0000.github.com/rosy/rosy.png?)

##### An inheritable AMD Framework.
[![Build Status](https://secure.travis-ci.org/ff0000/rosy.png?branch=master)](http://travis-ci.org/ff0000/rosy)

### Support

Rosy is [verified to work](https://github.com/ff0000/rosy/wiki/Unit-Tests) in the following browsers:

<table>
	<tr>
		<td><strong>Desktop</strong></td>
		<td><strong>iOS</strong></td>
		<td><strong>Android</strong></td>
	</tr>
	<tr>
		<td>Chrome (latest)</td>
		<td>Chrome (latest)</td>
		<td>Chrome (Nexus 7)</td>
	</tr>
	<tr>
		<td>Safari (latest)</td>
		<td>Safari (latest)</td>
		<td></td>
	</tr>
	<tr>
		<td>Firefox (latest)</td>
		<td></td>
		<td></td>
	</tr>
	<tr>
		<td>Internet Explorer (7+)</td>
		<td></td>
		<td></td>
	</tr>
</table>

### Documentation

For documentation and implementation details, check out the [wiki.](https://github.com/ff0000/rosy/wiki)
<br/><br/>

### License

**Released under the MIT License**

	Copyright (c) 2012 by RED Interactive Agency

	Permission is hereby granted, free of charge, to any person obtaining a copy
	of this software and associated documentation files (the "Software"), to deal
	in the Software without restriction, including without limitation the rights
	to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
	copies of the Software, and to permit persons to whom the Software is
	furnished to do so, subject to the following conditions:

	The above copyright notice and this permission notice shall be included in
	all copies or substantial portions of the Software.

	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
	IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
	FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
	AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
	LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
	OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
	THE SOFTWARE.
